@@ -2,8 +2,8 @@
 """
 :Author: HuangJingCan
 :Date: 2020-05-19 11:33:16
-:LastEditTime: 2021-04-15 14:48:26
-:LastEditors: HuangJingCan
+@LastEditTime: 2021-05-11 14:50:27
+@LastEditors: HuangJianYi
 :description: 用户处理
 """
 from seven_cloudapp.handlers.top_base import *
@@ -441,7 +441,7 @@ class GetHorseRaceLampListHandler(SevenBaseHandler):
             if len(prize_id_list) > 0:
                 prize_ids = ",".join(prize_id_list)
                 condition += " and prize_id not in (" + prize_ids + ")"
-        condition += f" and create_date>'{TimeHelper.add_hours_by_format_time(hour=7)}'"
+        condition += f" and create_date>'{TimeHelper.add_hours_by_format_time(hour=-1)}'"
         prize_roster_model = PrizeRosterModel(context=self)
         page_list = prize_roster_model.get_dict_list(condition, "", "create_date desc", str(page_size), "user_nick,prize_name,tag_id,machine_name", params)
         total = int(len(page_list))
