@@ -2,8 +2,8 @@
 """
 :Author: CaiYouBin
 :Date: 2020-05-12 20:04:54
-:LastEditTime: 2021-04-15 16:50:12
-:LastEditors: HuangJingCan
+@LastEditTime: 2021-05-12 11:19:39
+@LastEditors: HuangJianYi
 :description: 基础接口
 """
 from seven_cloudapp.handlers.top_base import *
@@ -333,8 +333,8 @@ class ActSaveHandler(SevenBaseHandler):
             act_info = act_info_model.get_entity_by_id(act_id)
 
             old_act_info = deepcopy(act_info)
-
-            act_info.act_name = act_name
+            if act_name:
+                act_info.act_name = act_name
             if is_release:
                 act_info.is_release = int(is_release)
             if close_word:
